@@ -1,7 +1,7 @@
 package Mojo::Webqq;
 use strict;
 use Carp ();
-$Mojo::Webqq::VERSION = "1.8.3";
+$Mojo::Webqq::VERSION = "1.8.4";
 use base qw(Mojo::Base);
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -34,6 +34,7 @@ has is_update_user          => 0;                            #是否定期更新
 has is_update_group         => 1;                            #是否定期更新群组信息
 has is_update_friend        => 1;                            #是否定期更新好友信息
 has is_update_discuss       => 1;                            #是否定期更新讨论组信息
+has update_interval         => 600;                          #定期更新的时间间隔
 
 has encrypt_method      => "perl";     #perl|js
 has tmpdir              => sub {File::Spec->tmpdir();};
@@ -99,9 +100,11 @@ has poll_failure_count_max  => 3;
 has message_queue           => sub { $_[0]->gen_message_queue };
 has ua                      => sub {
     require Mojo::UserAgent;
+    require Mojo::UserAgent::Proxy;
     #local $ENV{MOJO_USERAGENT_DEBUG} = $_[0]->ua_debug; 
     require Storable if $_[0]->keep_cookie;
     Mojo::UserAgent->new(
+        proxy              => sub{ my $proxy = Mojo::UserAgent::Proxy->new;$proxy->detect;$proxy}->(),
         max_redirects      => 7,
         request_timeout    => 120,
         inactivity_timeout => 120,
