@@ -1,5 +1,6 @@
 package Mojo::Webqq::Request;
 use List::Util qw(first);
+use Mojo::Util ();
 use File::Spec ();
 sub gen_url{
     my $self = shift;
@@ -51,7 +52,7 @@ sub _http_request{
                 $cb->($r,$ua,$tx);
             }
             elsif(defined $tx){
-                $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code}||"-") . " " . encode("utf8",$tx->error->{message}));
+                $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code}||"-") . " " . Mojo::Util::encode("utf8",$tx->error->{message}));
                 $cb->(undef,$ua,$tx);
             }
         });
@@ -77,11 +78,11 @@ sub _http_request{
                 return wantarray?($r,$self->ua,$tx):$r;
             }
             elsif(defined $tx){
-                $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code} || "-") . " " . encode("utf8",$tx->error->{message}));
+                $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code} || "-") . " " . Mojo::Util::encode("utf8",$tx->error->{message}));
                 next;
             }
         }
-        $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code}||"-") . " " . encode("utf8",$tx->error->{message})) if defined $tx;
+        $self->warn($tx->req->url->to_abs . " 请求失败: " . ($tx->error->{code}||"-") . " " . Mojo::Util::encode("utf8",$tx->error->{message})) if defined $tx;
         return wantarray?(undef,$self->ua,$tx):undef;
     }
 }
